pub struct Stripe {
pub devid: u64,
pub offset: u64,
pub dev_uuid: [u8; 16],
}Expand description
One stripe of a chunk: a physical placement on a device. For single-device
single/DUP the physical byte address of a logical address l within the
chunk is stripe.offset + (l - chunk_key.offset).
Fields
devid: u64devid — the device this stripe lives on.
offset: u64offset — the physical byte offset on the device where the chunk’s data
begins for this stripe.
dev_uuid: [u8; 16]dev_uuid — the device UUID.